globals[
  pos_vector;;position vector of the point being plotted
  prob_a    ;;probabilities of the a/1 or b/2 or c/3 
  prob_b    ;;translation matrices and vectors being
  prob_c    ;;used
  which     ;;which transformation was undergone (numbered 1 through 3)
  a_11 a_12 a_21 a_22
  b_11 b_12 b_21 b_22
  c_11 c_12 c_21 c_22
]


to setup
  ca
  reset-ticks
  ask patch 0 0[
    sprout 1[
      hide-turtle
    ]
  ]
  set pos_vector [0 0]
  repeat 1000 [
    transform-mat
    translate-vector]
end

to go
  transform-mat
  translate-vector
  lay-seed
  tick
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;Examples;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to sierpinski-triangle
  setup
  set rot1_x 0. set rot1_y 0. set rot2_x 0. set rot2_y 0. set rot3_x 0. set rot3_y 0.
  set scale1_x 0.5 set scale1_y 0.5 set scale2_x 0.5 set scale2_y 0.5 set scale3_x 0.5 set scale3_y 0.5
  set t1_x 0 set t1_y 0 set t2_x 30 set t2_y 0 set t3_x 15 set t3_y 27
end

to crystal
  setup
  set rot1_x -90. set rot1_y -90. set rot2_x 90. set rot2_y 90. set rot3_x 0. set rot3_y 0.
  set scale1_x 0.5 set scale1_y 0.5 set scale2_x 0.5 set scale2_y 0.5 set scale3_x 0.5 set scale3_y 0.5
  set t1_x 40 set t1_y 0 set t2_x 40 set t2_y 40 set t3_x 20 set t3_y 40
end

to spiral
  setup
  set rot1_x 0. set rot1_y 42.13 set rot2_x -30. set rot2_y -30. set rot3_x 0. set rot3_y 0.
  set scale1_x 0.143 set scale1_y 0.556 set scale2_x 0.944 set scale2_y 0.944 set scale3_x 0. set scale3_y 0.
  set t1_x 30 set t1_y 17 set t2_x 30 set t2_y 1 set t3_x 0 set t3_y 0
end

to snowflake
  setup
  set rot1_x 180. set rot1_y 180. set rot2_x 0. set rot2_y 180. set rot3_x 180. set rot3_y 0.
  set scale1_x 0.5 set scale1_y 0.5 set scale2_x 0.5 set scale2_y 0.5 set scale3_x 0.5 set scale3_y 0.5
  set t1_x 100 set t1_y 100 set t2_x 0 set t2_y 100 set t3_x 100 set t3_y 0
end

to starfish
  setup
  set rot1_x 0. set rot1_y 0. set rot2_x -40. set rot2_y -40. set rot3_x 0. set rot3_y 0.
  set scale1_x 0.25 set scale1_y 0.25 set scale2_x 0.95 set scale2_y 0.95 set scale3_x 0. set scale3_y 0.
  set t1_x 50 set t1_y 50 set t2_x 30 set t2_y 0 set t3_x 0 set t3_y 0
end

to dragon
  setup
  set rot1_x -45. set rot1_y -45. set rot2_x -45. set rot2_y -45. set rot3_x 0. set rot3_y 0.
  set scale1_x 0.707 set scale1_y 0.707 set scale2_x 0.707 set scale2_y 0.707 set scale3_x 0. set scale3_y 0.
  set t1_x 50 set t1_y 0 set t2_x 0 set t2_y 20 set t3_x 0 set t3_y 0
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;Linear Transformations;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;Modifies the elements of the transformation matrix using the information from the rotation and scale coordinates
to make-mat
  set a_11 precision (scale1_x * cos(rot1_x))3 set a_12 precision(scale1_y * sin(rot1_y))3 set a_21 precision(-1 * scale1_x * sin(rot1_x))3 set a_22 precision(scale1_y * cos(rot1_y))3
  set b_11 precision(scale2_x * cos(rot2_x))3 set b_12 precision(scale2_y * sin(rot2_y))3 set b_21 precision(-1 * scale2_x * sin(rot2_x))3 set b_22 precision(scale2_y * cos(rot2_y))3
  set c_11 precision(scale3_x * cos(rot3_x))3 set c_12 precision(scale3_y * sin(rot3_y))3 set c_21 precision(-1 * scale3_x * sin(rot3_x))3 set c_22 precision(scale3_y * cos(rot3_y))3
end

;;Selects a transformation to perform based on the probabilities calculated
;;in setup. Then, executes the corresponding matrix multiplication on the
;;position vector, modifying the values to the transformed values.

to transform-mat
  make-mat
  calculate-probability
  let ran_num random-float 1
  let x-cor 23
  let y-cor 52
  ifelse ran_num < prob_a[
    set x-cor (a_11 * (item 0 pos_vector) + a_12 * (item 1 pos_vector))
    set y-cor (a_21 * (item 0 pos_vector) + a_22 * (item 1 pos_vector))
    set which 1
  ]
  [
    ifelse ran_num < (prob_a + prob_b)[
      set x-cor (b_11 * (item 0 pos_vector) + b_12 * (item 1 pos_vector))
      set y-cor (b_21 * (item 0 pos_vector) + b_22 * (item 1 pos_vector))
      set which 2
    ]
    [
      set x-cor (c_11 * (item 0 pos_vector) + c_12 * (item 1 pos_vector))
      set y-cor (c_21 * (item 0 pos_vector) + c_22 * (item 1 pos_vector))
      set which 3
    ]
  ]
  set pos_vector (list x-cor y-cor)
end

;;Performing the translation based on the inputs from the
;;interface, corresponding to the matrix transformation
;;previously performed (indicated by which)
to translate-vector
  let x-cor 0
  let y-cor 0
  if which = 1[               ;;translation vector 1
    set x-cor (item 0 pos_vector) + t1_x
    set y-cor (item 1 pos_vector) + t1_y
  ]
  if which = 2[  ;;translation vector 2
    set x-cor (item 0 pos_vector) + t2_x
    set y-cor (item 1 pos_vector) + t2_y
  ]
  if which = 3
  [
    set x-cor (item 0 pos_vector) + t3_x  ;;translation vector 3
    set y-cor (item 1 pos_vector) + t3_y
  ]
  set pos_vector (list x-cor y-cor)
end

;;plotting a point at the coordinates indicated by
;;pos_vector
to lay-seed
  ask turtles [ set size 0.5 ]
  ask patch (item 0 pos_vector) (item 1 pos_vector)[
    sprout 1[
      if which = 1[ set color green ]
      if which = 2[ set color blue ]
      if which = 3 [ set color red ]
      set size 5
    ]
  ]
end

;;Calculating the probabilities that each of the
;;transformations is chosen based on the proportion
;;of the matrix's determinant versus the sum
to calculate-probability
  let det_a abs (a_11 * a_22) - (a_21 * a_12)
  let det_b abs (b_11 * b_22) - (b_21 * b_12)
  let det_c abs (c_11 * c_22) - (c_21 * c_12)
  let det_sum det_a + det_b + det_c
  set prob_a det_a / det_sum
  set prob_b det_b / det_sum
  set prob_c det_c / det_sum
end
@#$#@#$#@
GRAPHICS-WINDOW
240
19
718
413
-1
-1
3.0
1
10
1
1
1
0
1
1
1
-55
100
-20
100
0
0
1
ticks
30.0

TEXTBOX
1128
32
1278
50
Transformation Matrix
11
0.0
1

INPUTBOX
1048
50
1098
110
t1_x
50
1
0
Number

INPUTBOX
1048
110
1098
170
t1_y
0
1
0
Number

TEXTBOX
1048
32
1198
50
Translation
11
0.0
1

INPUTBOX
1048
174
1098
234
t2_x
0
1
0
Number

INPUTBOX
1048
234
1098
294
t2_y
20
1
0
Number

INPUTBOX
1048
300
1098
360
t3_x
0
1
0
Number

INPUTBOX
1048
360
1098
420
t3_y
0
1
0
Number

BUTTON
57
369
174
402
Go forever
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
56
74
185
107
Sierpinski Triangle
sierpinski-triangle
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
56
105
185
138
Crystal
crystal
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
56
136
185
169
Spiral
spiral
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
56
167
185
200
Square Snowflake
snowflake
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
56
199
185
232
Starfish
starfish
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
56
46
206
68
Fractal Examples
16
0.0
1

TEXTBOX
60
279
210
301
Procedures
16
0.0
1

TEXTBOX
729
27
879
49
Create your own
18
0.0
1

TEXTBOX
727
66
895
178
To make your own IFS fractal, enter the values for the rotation and scale, along with the translation vectors. then click \"Setup New IFS\" below, and click one of the \"Go\" buttons on the lower right. 
11
0.0
1

BUTTON
56
231
185
264
Dragon Curve
dragon
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
908
50
958
110
rot1_x
-45
1
0
Number

INPUTBOX
908
110
958
170
rot1_y
-45
1
0
Number

INPUTBOX
975
50
1034
110
scale1_x
0.707
1
0
Number

INPUTBOX
975
110
1034
170
scale1_y
0.707
1
0
Number

INPUTBOX
907
174
957
234
rot2_x
-45
1
0
Number

INPUTBOX
907
234
957
294
rot2_y
-45
1
0
Number

INPUTBOX
977
174
1034
234
scale2_x
0.707
1
0
Number

INPUTBOX
977
234
1034
294
scale2_y
0.707
1
0
Number

INPUTBOX
907
300
957
360
rot3_x
0
1
0
Number

INPUTBOX
907
360
957
420
rot3_y
0
1
0
Number

INPUTBOX
977
300
1034
360
scale3_x
0
1
0
Number

INPUTBOX
977
360
1034
420
scale3_y
0
1
0
Number

TEXTBOX
910
32
956
50
Rotation
11
0.0
1

TEXTBOX
978
32
1017
50
Scale
11
0.0
1

MONITOR
1130
50
1187
95
NIL
a_11
3
1
11

MONITOR
1187
50
1244
95
NIL
a_12
3
1
11

MONITOR
1130
93
1187
138
NIL
a_21
3
1
11

MONITOR
1187
93
1244
138
NIL
a_22
3
1
11

MONITOR
1131
172
1188
217
NIL
b_11
3
1
11

MONITOR
1188
172
1245
217
NIL
b_12
3
1
11

MONITOR
1131
216
1188
261
NIL
b_21
3
1
11

MONITOR
1188
216
1245
261
NIL
b_22
3
1
11

MONITOR
1133
298
1190
343
NIL
c_11
3
1
11

MONITOR
1188
298
1245
343
NIL
c_12
3
1
11

MONITOR
1133
343
1190
388
NIL
c_21
3
1
11

MONITOR
1188
343
1245
388
NIL
c_22
3
1
11

BUTTON
57
337
173
370
Go 100 iterations
repeat 100 [go]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
11
10
247
39
Iterated Function Systems
18
95.0
1

TEXTBOX
729
273
888
390
Points generated by the first transformation are colored green, those from the second transformation are colored blue, and points from the third transformation are red.
11
0.0
1

BUTTON
57
306
173
339
Go 1 iteration
repeat 1 [go]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
726
184
842
217
Setup New IFS
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
728
251
902
283
Note on the color scheme:
13
0.0
1

@#$#@#$#@
## WHAT IS IT?

This model demonstrates how to use iterated function systems to represent fractals. An iterated function system, or IFS, consists of a set of affine transformations that are performed on points. There are four kinds of affine transformations possible in this model:<br> 
	1. Translation
	2. Scaling
	3. Reflection
	4. Rotation <br> 
A translation is performed on a point by adding the point to a translation vector. Then, a point can be scaled if it is multiplied by a scalar constant. Finally, a point can be reflected and rotated via matrix multiplication. In our representation, the scaling of the point is incorporated into the matrix multiplication, so that a single operation scales, reflects, and rotates the point. With each iteration, there are any number of different transformations that could be performed, each with an associated probability of occurring. This model supports a maximum of three different transformations. A fractal is generated after a few thousand iterations, which are successive transformations of the original point.

## HOW IT WORKS

The model starts with a turtle placed on a patch in the world. The matrices (a, b, c) and translation vectors (t1, t2, t3) located on the right-hand side have inputs where you can type in the component values. At a given iteration, the probability of each transformation occurring is equal to the proportion of that matrix's determinant over the sum of all determinants (see below for more details). A transformation is chosen according to this probability and is performed on the point, producing a new point to be transformed at the next iteration.   After a few thousand iterations, a coherent image will emerge in the worldview.

## HOW TO USE IT

Start out by selecting some of the examples. Press the button corresponding to the fractal you wish to view, and then select "Go". After you have investigated these, you can try creating your own fractal. Simply enter the desired values for the scaling, rotation, and translation into the input boxes on the right-hand side. If you only want to deal with two different transformations, enter only 0s into one matrix and its corresponding vector.

## THINGS TO NOTICE

While working through the examples, try to notice patterns with how the transformation-matrix values relate to the patterns visible on the image. How does the image change when you modify the rotations? Multiply all of them by -1? Switch the x and y? Do the same with the translation vectors. How does the image change when you multiply all of the translation values by a number?

## THINGS TO TRY

After playing around with the preset IFS fractals, try designing your own. You could make a new image just by changing the values preset for the Sierpinski triangle, or the spiral. With IFS, the fractal possibilities are much greater than with the L-systems model, which was simpler and more constrained.

## NOTE ON PROBABILITIES
At each iteration, the probability that a given transformation will be chosen is equal to the determinant of that transformation's matrix divided by the sum of all transformations' matrices. <br> 

Given a matrix:<br> 
a   b
c   d <br> 
the determinant is equal to a*d - b*c. To calculate the probability, we compute the determinants of all the matrices, then add their absolute values. The probability of one transformation is its determinant over the sum of all matrices' determinants.
To explore this further, create monitors that display each transformation's probability of being chosen (hint: they're all global variables). Then, calculate the determinant of each matrix to verify that the probability calculation is correct.

## CREDITS AND REFERENCES

This model is part of the Fractals series of the Complexity Explorer project.  It was inspired in part by the IFS Construction Kit, developed by Larry Riddle (http://ecademy.agnesscott.edu/~lriddle/ifskit/index.htm).  
 
Main Author:  Vicki Niu

Contributions from: Melanie Mitchell

Netlogo:  Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.


## HOW TO CITE

If you use this model, please cite it as: Iterated Function Systems model, Complexity Explorer project, http://complexityexplorer.org

## COPYRIGHT AND LICENSE

Copyright 2016 Santa Fe Institute.

This model is licensed by the Creative Commons Attribution-NonCommercial-ShareAlike International (http://creativecommons.org/licenses/). This states that you may copy, distribute, and transmit the work under the condition that you give attribution to ComplexityExplorer.org, and your use is for non-commercial purposes.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
